@@ -20,7 +20,7 @@ from longling.Architecture.utils import binary_legal_input
 from longling.lib.path import abs_current_dir, path_append
 from longling.lib.regex import default_variable_replace as dvr
 from longling.lib.utilog import config_logging, LogLevel
-from longling.lib.yaml import FoldedString, ordered_yaml_load, dump_folded_yaml
+from longling.lib.yaml_helper import FoldedString, ordered_yaml_load, dump_folded_yaml
 
 from . import config
 
