@@ -46,16 +46,8 @@ class Configuration(parser.Configuration):
 
     # 优化器设置
     optimizer, optimizer_params = get_optimizer_cfg(name="base")
-    # lr_params = {
-    #     "learning_rate": optimizer_params["learning_rate"],
-    #     "step": 100,
-    #     "max_update_steps": get_update_steps(
-    #         update_epoch=10,
-    #         batches_per_epoch=1000,
-    #     ),
-    # }
     # lr_params 中包含 update_params 时，学习率衰减方式运行时确定
-    lr_params = {}
+    lr_params = {"update_params": {}}
 
     # 更新保存参数，一般需要保持一致
     train_select = _select
@@ -78,7 +70,7 @@ class Configuration(parser.Configuration):
     # 说明
     caption = ""
 
-    def __init__(self, params_json=None, **kwargs):
+    def __init__(self, params_path=None, **kwargs):
         """
         Configuration File, including categories:
 
@@ -91,7 +83,7 @@ class Configuration(parser.Configuration):
 
         Parameters
         ----------
-        params_json: str
+        params_path: str
             The path to configuration file which is in json format
         kwargs:
             Parameters to be reset.
@@ -104,8 +96,8 @@ class Configuration(parser.Configuration):
         )
 
         params = self.class_var
-        if params_json:
-            params.update(self.load_cfg(params_json=params_json))
+        if params_path:
+            params.update(self.load_cfg(cfg_path=params_path))
         params.update(**kwargs)
 
         for key in params:
@@ -163,9 +155,9 @@ class Configuration(parser.Configuration):
             self.model_dir, "configuration.json", to_str=True
         )
 
-    def dump(self, cfg_path=None, override=False):
+    def dump(self, cfg_path=None, override=True, file_format=None):
         cfg_path = self.cfg_path if cfg_path is None else cfg_path
-        super(Configuration, self).dump(cfg_path, override)
+        super(Configuration, self).dump(cfg_path, override, file_format=file_format)
 
     def var2val(self, var):
         return eval(var2exp(
@@ -185,7 +177,7 @@ def directory_check(class_obj):
 
 if __name__ == '__main__':
     # Advise: firstly checkout whether the directory is correctly (step 1) and
-    # then generate the paramters configuation file
+    # then generate the parameters configuration file
     # to check the details (step 2)
     stage = 1
     # step 1
