@@ -10,20 +10,18 @@ from tqdm import tqdm
 from longling.ML.MxnetHelper.toolkit.ctx import split_and_load
 
 
-def _fit_f(_net, _data, bp_loss_f, loss_function, loss_monitor):
+def _fit_f(_net, _data, loss_function, loss_monitor=None):
     data, label = _data
     # todo modify the input to net
     output = _net(data)
-    bp_loss = None
+    loss_list = []
     for name, func in loss_function.items():
-        # todo modify the input to func
         loss = func(output, label)
-        if name in bp_loss_f:
-            bp_loss = loss
-        loss_value = nd.mean(loss).asscalar()
-        if loss_monitor:
-            loss_monitor.update(name, loss_value)
-    return bp_loss
+        loss_list.append(loss)
+        # loss_value = nd.mean(loss).asscalar()
+        # if loss_monitor:
+        #     loss_monitor.update(name, loss_value)
+    return sum(loss_list)
 
 
 def eval_f(_net, test_data, ctx=mx.cpu()):
@@ -48,8 +46,8 @@ def eval_f(_net, test_data, ctx=mx.cpu()):
 
 
 def fit_f(net, batch_size, batch_data,
-          trainer, bp_loss_f, loss_function, loss_monitor=None,
-          ctx=mx.cpu()):
+          trainer, loss_function, loss_monitor=None,
+          ctx=mx.cpu(), fit_step_func=_fit_f):
     """
     Defined how each step of batch train goes
 
@@ -64,15 +62,14 @@ def fit_f(net, batch_size, batch_data,
         The batch data for train
     trainer:
         The trainer used to update the parameters of the net
-    bp_loss_f: dict with only one value and one key
-        The function to compute the loss for the procession
-        of back propagation
     loss_function: dict of function
-        Some other measurement in addition to bp_loss_f
+        The functions to compute the loss for the procession
+        of back propagation
     loss_monitor: LossMonitor
         Default to ``None``
     ctx: Context or list of Context
         Defaults to ``mx.cpu()``.
+    fit_step_func: function
 
     Returns
     -------
@@ -85,10 +82,13 @@ def fit_f(net, batch_size, batch_data,
 
     with autograd.record():
         for _data in ctx_data:
-            bp_loss = _fit_f(
-                net, _data, bp_loss_f, loss_function, loss_monitor
+            bp_loss = fit_step_func(
+                net, _data, loss_function, loss_monitor
             )
-            assert bp_loss is not None
             bp_loss.backward()
+
     # todo: confirm whether the train step is equal to batch_size
-    trainer.step(batch_size)
+    if batch_size is not None:
+        trainer.step(batch_size)
+    else:
+        trainer.step(len(batch_data[0]))
