@@ -2,14 +2,14 @@
 # 2020/8/16 @ tongshiwei
 
 import logging
-from longling.ML.MxnetHelper.toolkit.init import net_initialize, load_net
+from longling.ML.MxnetHelper.toolkit import net_initialize, load_net
 
 
 def net_init(
         net, cfg=None,
         force_init=False,
         allow_reinit=True, logger=logging, initialized=False, model_file=None,
-        initializer_kwargs=None, **kwargs
+        initializer_kwargs=None, *args, **kwargs
 ):
     if initialized and not force_init:
         logger.warning("model has been initialized, skip model_init")
@@ -29,6 +29,6 @@ def net_init(
             initializer_kwargs = {} if initializer_kwargs is None else initializer_kwargs
             net_initialize(net, cfg.ctx, **initializer_kwargs)
         else:
-            logger.info(
+            logger.error(
                 "model doesn't exist, target file: %s" % model_file
             )
