@@ -1,47 +1,12 @@
 # coding: utf-8
 # create by tongshiwei on 2019/4/12
 import warnings
-from copy import deepcopy
 
 import mxnet as mx
 
-__all__ = ["get_optimizer_cfg", "get_lr_scheduler", "get_update_steps"]
+from longling.ML.DL import get_optimizer_cfg
 
-optimizers = {
-    "base": (
-        "Adam",
-        {
-            "learning_rate": 10e-3,
-            "wd": 10e-4,
-            "clip_gradient": 1,
-        }
-    ),
-    "recurrent": (
-        "RMSProp",
-        {
-            "learning_rate": 10e-4,
-            "wd": 10e-4,
-            "clip_gradient": 1,
-        }
-    ),
-    "stable": (
-        "sgd",
-        {
-            "learning_rate": 10e-2,
-            "wd": 10e-4,
-            "clip_gradient": 1,
-            "momentum": 0.9,
-        }
-    ),
-    "word_embedding": (
-        "adagrad",
-        {
-            "learning_rate": 10e-2,
-            "wd": 10e-4,
-            "clip_gradient": 1,
-        }
-    )
-}
+__all__ = ["get_optimizer_cfg", "get_lr_scheduler", "get_update_steps"]
 
 
 def get_lr_params(batches_per_epoch, lr, update_epoch, epoch_update_freq=1, *args, **kwargs):
@@ -78,16 +43,6 @@ def get_lr_scheduler(learning_rate, step=None, max_update_steps=None,
     )
 
 
-def get_optimizer_cfg(name):
-    try:
-        optimizer, optimizer_params = optimizers[name]
-    except KeyError:
-        raise KeyError("the name should be in: %s" % ", ".join(optimizers))
-    optimizer_params = deepcopy(optimizer_params)
-
-    return optimizer, optimizer_params
-
-
 def plot_schedule(schedule_fn, iterations=1500):
     import matplotlib.pyplot as plt
     # Iteration count starting at 1
