@@ -7,4 +7,6 @@
 # from .splitter.iterable_splitter import *
 # from .splitter.splitter import Splitter
 
+from .feature import ID2Feature
+from .sampler import *
 from .split import train_test, train_valid_test, kfold
