@@ -2,10 +2,13 @@
 # create by tongshiwei on 2019/7/2
 # PYTEST_DONT_REWRITE
 
-__all__ = ["path_append", "file_exist", "abs_current_dir", "type_from_name"]
+__all__ = ["path_append", "file_exist", "abs_current_dir", "type_from_name", "tmpfile"]
 
 import os
 from pathlib import PurePath
+import uuid
+import tempfile
+from contextlib import contextmanager
 
 
 def type_from_name(filename):
@@ -48,12 +51,12 @@ def path_append(path, *addition, to_str=False):
     return path
 
 
-def file_exist(file_path):
+def file_exist(filepath):
     """判断文件是否存在"""
-    return os.path.isfile(file_path)
+    return os.path.isfile(filepath)
 
 
-def abs_current_dir(file_path):
+def abs_current_dir(filepath):
     """
     获取文件所在目录的绝对路径
 
@@ -64,4 +67,25 @@ def abs_current_dir(file_path):
         abs_current_dir(__file__)
 
     """
-    return os.path.abspath(os.path.dirname(file_path))
+    return os.path.abspath(os.path.dirname(filepath))
+
+
+@contextmanager
+def tmpfile(suffix=None, prefix=None, dir=None):
+    """
+    Create a temporary file, which will automatically cleaned after used (outside "with" closure).
+
+    Examples
+    --------
+
+    .. code-block ::
+
+        with tmpfile("test_tmp") as tmp:
+            print(tmp)
+            with open(tmp, mode="w") as wf:
+                print("hello world", file=wf)
+    """
+    prefix = prefix if prefix is not None else tempfile.gettempprefix() + str(uuid.uuid4())[:6]
+    filename = prefix + suffix if suffix is not None else prefix
+    with tempfile.TemporaryDirectory(dir=dir) as tmpdir:
+        yield os.path.join(tmpdir, filename)
